@@ -146,7 +146,7 @@ int main(int argc, char **orig_argv)
   //parse command line options
   int option;
   while ((option = getopt(data->argc, data->argv,
-          "m:O:DvifKkwleqnasrc:d:o:t:p:g:hQN12T:XxPE:A:S:G:F:C:I:")) != -1)
+          "Mm:O:DvifKkwleqnasrc:d:o:t:p:g:hQN12T:XxPE:A:S:G:F:C:I:")) != -1)
   {
     switch (option)
     {
@@ -282,6 +282,10 @@ int main(int argc, char **orig_argv)
         opt->m3u_arg = strdup(optarg);
         mp3splt_set_m3u_filename(state, opt->m3u_arg);
         break;
+      case 'M':
+        mp3splt_set_int_option(state,
+            SPLT_OPT_DECODE_AND_WRITE_FLAC_MD5SUM_FOR_CREATED_FILES, SPLT_TRUE);
+        break;
       case 'F':
         opt->F_option = SPLT_TRUE;
         opt->full_log_arg = strdup(optarg);
@@ -487,9 +491,11 @@ int main(int argc, char **orig_argv)
     int gap = -200, nt = -200, rm = -200, shots = -200;
     float min_track_join = -200;
     float keep_silence_left = -200, keep_silence_right = -200;
+    int warn_if_no_auto_adjust = -200, err_if_no_auto_adjust = -200;
     int parsed_p_options = 
       parse_silence_options(opt->param_args, &th, &gap, &nt, &off, &rm, &min, &min_track_length,
-          &shots, &min_track_join, &keep_silence_left, &keep_silence_right);
+          &shots, &min_track_join, &keep_silence_left, &keep_silence_right,
+          &warn_if_no_auto_adjust, &err_if_no_auto_adjust);
     if (parsed_p_options < 1)
     {
       print_error_exit(_("bad argument for -p option. No valid value was recognized !"), data);
@@ -540,6 +546,14 @@ int main(int argc, char **orig_argv)
     {
       mp3splt_set_int_option(state, SPLT_OPT_PARAM_REMOVE_SILENCE, rm);
     }
+    if (warn_if_no_auto_adjust != -200)
+    {
+      mp3splt_set_int_option(state, SPLT_OPT_WARN_IF_NO_AUTO_ADJUST_FOUND, SPLT_TRUE);
+    }
+    if (err_if_no_auto_adjust != -200)
+    {
+      mp3splt_set_int_option(state, SPLT_OPT_STOP_IF_NO_AUTO_ADJUST_FOUND, SPLT_TRUE);
+    }
   }
 
   int output_format_error = SPLT_OK;
@@ -774,29 +788,31 @@ int main(int argc, char **orig_argv)
             err = mp3splt_remove_tags_of_skippoints(state);
             process_confirmation_error(err, data);
           }
-          else
+          else if (strncmp(opt->cddb_arg, "query", 5) == 0)
           {
-            if (strncmp(opt->cddb_arg, "query", 5) == 0)
+            if (j == 0)
             {
-              if (j == 0)
+              int ambigous = parse_query_arg(opt,opt->cddb_arg);
+              if (ambigous)
               {
-                int ambigous = parse_query_arg(opt,opt->cddb_arg);
-                if (ambigous)
-                {
-                  print_warning(_("freedb query format ambigous !"));
-                }
-
-                do_freedb_search(data);
+                print_warning(_("freedb query format ambigous !"));
               }
 
-              err = mp3splt_import(state, CDDB_IMPORT, MP3SPLT_CDDBFILE);
-              process_confirmation_error(err, data);
-            }
-            else
-            {
-              err = mp3splt_import(state, CDDB_IMPORT, opt->cddb_arg);
-              process_confirmation_error(err, data);
+              do_freedb_search(data);
             }
+
+            err = mp3splt_import(state, CDDB_IMPORT, MP3SPLT_CDDBFILE);
+            process_confirmation_error(err, data);
+          }
+          else if (strncmp(opt->cddb_arg, "internal_sheet", 14) == 0)
+          {
+            err = mp3splt_import(state, PLUGIN_INTERNAL_IMPORT, current_filename);
+            process_confirmation_error(err, data);
+          }
+          else
+          {
+            err = mp3splt_import(state, CDDB_IMPORT, opt->cddb_arg);
+            process_confirmation_error(err, data);
           }
         }
         else if (opt->audacity_labels_arg)
@@ -875,19 +891,20 @@ int main(int argc, char **orig_argv)
       process_confirmation_error(err, data);
     }
 
-    if (opt->c_option && err >= 0 && !opt->q_option)
+    if (opt->c_option && err >= 0 && !opt->q_option &&
+        !(strncmp(opt->cddb_arg, "internal_sheet", 14) == 0))
     {
-      print_message(_("\n +-----------------------------------------------------------------------------+\n"
-            " |NOTE: When you use cddb/cue, split files might be not very precise due to:|\n"
-            " |1) Who extracts CD tracks might use \"Remove silence\" option. This means that |\n"
-            " |   the large mp3 file is shorter than CD Total time. Never use this option.  |\n"
-            " |2) Who burns CD might add extra pause seconds between tracks.  Never do it.  |\n"
-            " |3) Encoders might add some padding frames so  that  file is longer than CD.  |\n"
-            " |4) There are several entries of the same cd on CDDB, find the best for yours.|\n"
-            " |   Usually you can find the correct splitpoints, so good luck!  |\n"
-            " +-----------------------------------------------------------------------------+\n"
-            " | TRY TO ADJUST SPLITS POINT WITH -a OPTION. Read man page for more details!  |\n"
-            " +-----------------------------------------------------------------------------+\n"));
+      print_message(_("\n +------------------------------------------------------------------------------+\n"
+            " | NOTE: When you use cddb/cue, split files might be not very precise due to:   |\n"
+            " | 1) Who extracts CD tracks might use \"Remove silence\" option. This means that |\n"
+            " |    the large mp3 file is shorter than CD Total time. Never use this option.  |\n"
+            " | 2) Who burns CD might add extra pause seconds between tracks.  Never do it.  |\n"
+            " | 3) Encoders might add some padding frames so  that  file is longer than CD.  |\n"
+            " | 4) There are several entries of the same cd on CDDB, find the best for yours.|\n"
+            " |    Usually you can find the correct splitpoints, so good luck!               |\n"
+            " +------------------------------------------------------------------------------+\n"
+            " |  TRY TO ADJUST SPLITS POINT WITH -a OPTION. Read man page for more details!  |\n"
+            " +------------------------------------------------------------------------------+\n"));
     }
 
     if (data->number_of_filenames > 1)
