@@ -2,7 +2,7 @@
  * Mp3Splt -- Utility for mp3/ogg splitting without decoding
  *
  * Copyright (c) 2002-2005 M. Trotta - <mtrotta@users.sourceforge.net>
- * Copyright (c) 2005-2012 Alexandru Munteanu - <io_fx@yahoo.fr>
+ * Copyright (c) 2005-2013 Alexandru Munteanu - <m@ioalex.net>
  *
  * http://mp3splt.sourceforge.net
  *
@@ -18,7 +18,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #ifndef OPTIONS_MANAGER_H
@@ -37,6 +37,8 @@ typedef struct {
   short r_option;
   //output filename, output directory, seekable
   short o_option; short d_option; short k_option;
+  //keep original tags when using cddb or cue import
+  short K_option;
   //custom tags, no tags, quiet option
   short g_option; short n_option; short q_option;
   short E_option;
@@ -52,6 +54,7 @@ typedef struct {
   //info -i option, m3u file option
   short i_option;
   short m_option;
+  short F_option;
   short S_option;
   int S_option_value;
   char *tags_from_fname_regex_arg;
@@ -59,10 +62,10 @@ typedef struct {
   char *cddb_arg; char *dir_arg; char *param_args;
   char *export_cue_arg;
   char *audacity_labels_arg;
-  //the m3u filename
-  char *m3u_arg;
   //custom tags with -g
   char *custom_tags;
+  char *m3u_arg;
+  char *full_log_arg;
   //output format (-o)
   char *output_format;
   //the parsed freedb_search_type
